Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2827)

Unified Diff: content/public/browser/desktop_media_id.h

Issue 615133002: Add support for a virtual display on ChromeOS (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Remove ash/ dep from content Created 5 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/content_browser.gypi ('k') | content/public/browser/desktop_media_id.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/public/browser/desktop_media_id.h
diff --git a/content/public/browser/desktop_media_id.h b/content/public/browser/desktop_media_id.h
index 639a3c8d43054299e098fa289fdf7a4e8d9bc2ab..2c4a868641f08a903aaa20429688fc96ecc64d18 100644
--- a/content/public/browser/desktop_media_id.h
+++ b/content/public/browser/desktop_media_id.h
@@ -27,6 +27,7 @@ struct CONTENT_EXPORT DesktopMediaID {
TYPE_SCREEN,
TYPE_WINDOW,
TYPE_AURA_WINDOW,
+ TYPE_AURA_VIRTUAL_SCREEN,
};
typedef intptr_t Id;
@@ -35,8 +36,13 @@ struct CONTENT_EXPORT DesktopMediaID {
// type TYPE_AURA_WINDOW that corresponds to that |window|.
static DesktopMediaID RegisterAuraWindow(aura::Window* window);
+ // Register the |window| as the aura::Window backing the virtual screen.
+ static void RegisterVirtualScreenAuraWindow(aura::Window* window);
+
// For DesktopMediaID of type TYPE_AURA_WINDOW returns the |window| that was
// previously registered using RegisterAuraWindow().
static aura::Window* GetAuraWindowById(const DesktopMediaID& id);
#endif // defined(USE_AURA)
« no previous file with comments | « content/content_browser.gypi ('k') | content/public/browser/desktop_media_id.cc » ('j') | no next file with comments »
@@ -35,8 +36,13 @@ struct CONTENT_EXPORT DesktopMediaID {
// For DesktopMediaID of type TYPE_AURA_WINDOW returns the |window| that was
- // previously registered using RegisterAuraWindow().
+ // previously registered using RegisterAuraWindow() and for
+ // TYPE_AURA_VIRTUAL_SCREEN returns the |window| that was previously
+ // registered using RegisterVirtualScreenAuraWindow().
static aura::Window* GetAuraWindowById(const DesktopMediaID& id);
#endif // defined(USE_AURA)

Powered by Google App Engine
This is Rietveld 408576698